==> quidproquo-actionprocessor-awslambda-0.0.242.tgz: package/lib/esm/logic/dynamo/getLogByCorrelation.js <==
import { DynamoDBClient, QueryCommand } from '@aws-sdk/client-dynamodb';
import { createAwsClient } from '../createAwsClient';
export async function getLogByCorrelation(tableName, region, correlation) {
    const dynamoDBClient = createAwsClient(DynamoDBClient, { region });
    const queryParams = {
        TableName: tableName,
        IndexName: 'CorrelationIndex',
        KeyConditionExpression: 'correlation = :correlation',
        ExpressionAttributeValues: {
            ':correlation': { S: correlation },
        },
    };
    try {
        const queryResult = await dynamoDBClient.send(new QueryCommand(queryParams));
        const items = (queryResult.Items || []).map((i) => {
            const [startedAt, correlation] = i.startedAtWithCorrelation.S?.split('#') || [];
            const metaData = {
                generic: i.generic.S || '',
                runtimeType: i.runtimeType.S,
                error: i.error?.S,
                startedAt: startedAt,
                correlation,
                moduleName: i.moduleName.S || '',
                fromCorrelation: i.fromCorrelation?.S,
                executionTimeMs: i.executionTimeMs?.N ? parseInt(i.executionTimeMs.N) : 0,
            };
            return metaData;
        });
        const [result] = items;
        if (!result) {
            throw new Error(`Failed to find log with correlation: ${correlation}`);
        }
        return result;
    }
    catch (err) {
        console.error(`Failed to find log: ${err}`);
        throw err;
    }
}

==> quidproquo-actionprocessor-awslambda-0.0.255.tgz: package/lib/esm/logic/dynamo/getLogByCorrelation.js <==
import { DynamoDBClient, QueryCommand } from '@aws-sdk/client-dynamodb';
import { createAwsClient } from '../createAwsClient';
export async function getLogByCorrelation(tableName, region, correlation) {
    const dynamoDBClient = createAwsClient(DynamoDBClient, { region });
    const queryParams = {
        TableName: tableName,
        IndexName: 'CorrelationIndex', // use the GSI
        KeyConditionExpression: 'correlation = :correlation',
        ExpressionAttributeValues: {
            ':correlation': { S: correlation },
        },
    };
    try {
        const queryResult = await dynamoDBClient.send(new QueryCommand(queryParams));
        const items = (queryResult.Items || []).map((i) => {
            const [startedAt, correlation] = i.startedAtWithCorrelation.S?.split('#') || [];
            const metaData = {
                generic: i.generic.S || '',
                runtimeType: i.runtimeType.S,
                error: i.error?.S,
                startedAt: startedAt,
                correlation,
                moduleName: i.moduleName.S || '',
                fromCorrelation: i.fromCorrelation?.S,
                executionTimeMs: i.executionTimeMs?.N ? parseInt(i.executionTimeMs.N) : 0,
            };
            return metaData;
        });
        const [result] = items;
        if (!result) {
            throw new Error(`Failed to find log with correlation: ${correlation}`);
        }
        return result;
    }
    catch (err) {
        console.error(`Failed to find log: ${err}`);
        throw err;
    }
}
